@@ -2,8 +2,9 @@ from functools import partial, wraps
 from typing import Callable, Union
 
 from django.core.cache import cache as dj_cache
+from django.core.cache.backends.base import DEFAULT_TIMEOUT
 
-default = "ariadne-django-ext"
+default = object()
 delimiter = "::"
 
 
@@ -18,7 +19,7 @@ def cache_keygen(info, key):
     )
 
 
-def cache(key: Union[str, Callable], **cache_kwargs):
+def cache(key: Union[str, Callable], timeout=DEFAULT_TIMEOUT, version=None):
     def wrap_resolver(resolver: Callable):
         @wraps(resolver)
         def wrapper(parent, info, **kwargs):
@@ -26,12 +27,12 @@ def cache(key: Union[str, Callable], **cache_kwargs):
             cache_key = key(parent, info, **kwargs) if callable(key) else key
             if cache_key is not None:
                 cache_key = cache_keygen(info, cache_key)
-                cached = dj_cache.get(cache_key, default, **cache_kwargs)
+                cached = dj_cache.get(cache_key, default, version)
                 if cached != default:
                     return cached
 
                 result = resolve()
-                dj_cache.add(cache_key, result, **cache_kwargs)
+                dj_cache.add(cache_key, result, timeout, version)
                 return result
             return resolve()
 
