@@ -2,17 +2,18 @@ from ariadne import SchemaDirectiveVisitor
 from django.core.exceptions import PermissionDenied
 from graphql import default_field_resolver
 
+from .utils import is_authenticated
+
 
 class IsAuthenticatedDirective(SchemaDirectiveVisitor):
     def visit_field_definition(self, field, _):
         original_resolver = field.resolve or default_field_resolver
 
         def resolve_for_authenticated_user(parent, info, **kwargs):
-            user = info.context["request"].user
-            if user and user.is_authenticated:
-                return original_resolver(parent, info, user=user, **kwargs)
-            else:
-                raise PermissionDenied()
+            user = is_authenticated(
+                info.context["request"], is_active=True, raise_exception=True
+            )
+            return original_resolver(parent, info, user=user, **kwargs)
 
         field.resolve = resolve_for_authenticated_user
         return field
@@ -23,11 +24,10 @@ class IsStaffDirective(SchemaDirectiveVisitor):
         original_resolver = field.resolve or default_field_resolver
 
         def resolve_for_authenticated_user(parent, info, **kwargs):
-            user = info.context["request"].user
-            if user and user.is_authenticated and user.is_staff:
+            user = is_authenticated(info.context["request"], is_active=True)
+            if user and user.is_staff:
                 return original_resolver(parent, info, user=user, **kwargs)
-            else:
-                raise PermissionDenied()
+            raise PermissionDenied()
 
         field.resolve = resolve_for_authenticated_user
         return field
